@@ -104,8 +104,12 @@ class CARDTargetFeatureProvider(StashableBase):
 
             for matchD in matchDL:
                 #
-                begSeqId = matchD["targetStart"]
-                endSeqId = matchD["targetEnd"]
+                if "alignedRegions" in matchD:
+                    begSeqId = ",".join([str(arD["targetBegin"]) for arD in matchD["alignedRegions"]])
+                    endSeqId = ",".join([str(arD["targetEnd"]) for arD in matchD["alignedRegions"]])
+                else:
+                    begSeqId = matchD["targetStart"]
+                    endSeqId = matchD["targetEnd"]
                 tCmtD = self.__decodeComment(matchD["target"])
                 entryId = tCmtD["entityId"].split("_")[0]
                 entityId = tCmtD["entityId"].split("_")[1]
