@@ -186,6 +186,15 @@ class ChEMBLTargetCofactorProvider(StashableBase):
                     if not actL:
                         logger.debug("No ChEMBL cofactors for %s %s", chemblId, unpId)
                     # ---
+                    if "alignedRegions" in matchD:
+                        tBegSeqId = ",".join([str(arD["targetBegin"]) for arD in matchD["alignedRegions"]])
+                        qBegSeqId = ",".join([str(arD["queryBegin"]) for arD in matchD["alignedRegions"]])
+                        alignLen = ",".join([str(arD["targetEnd"] - arD["targetBegin"]) for arD in matchD["alignedRegions"]])
+                    else:
+                        tBegSeqId = matchD["targetStart"]
+                        qBegSeqId = matchD["queryStart"]
+                        alignLen = matchD["alignLen"]
+                    # ---
                     rD = {
                         "entry_id": entryId,
                         "entity_id": entityId,
@@ -198,9 +207,11 @@ class ChEMBLTargetCofactorProvider(StashableBase):
                         "assignment_version": assignVersion,
                         "query_taxonomy_id": int(queryTaxId) if queryTaxId else None,
                         "target_taxonomy_id": int(matchD["targetTaxId"]) if "targetTaxId" in matchD else None,
-                        "target_beg_seq_id": matchD["targetStart"],
-                        "query_beg_seq_id": matchD["queryStart"],
-                        "align_length": matchD["alignLen"],
+                        #
+                        "target_beg_seq_id": tBegSeqId,
+                        "query_beg_seq_id": qBegSeqId,
+                        "align_length": alignLen,
+                        #
                         "taxonomy_match_status": matchD["taxonomyMatchStatus"] if "taxonomyMatchStatus" in matchD else None,
                         "lca_taxonomy_id": matchD["lcaTaxId"] if "lcaTaxId" in matchD else None,
                         "lca_taxonomy_name": matchD["lcaTaxName"] if "lcaTaxName" in matchD else None,
